@@ -166,7 +166,7 @@ from ae.core import DEBUG_LEVEL_VERBOSE
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action   # type: ignore
 
 
-__version__ = '0.1.16'
+__version__ = '0.1.17'
 
 
 NODE_FILE_PREFIX = 'node_'  #: file name prefix for node imports/exports
@@ -213,7 +213,7 @@ class LiszDataMixin(ABC):
         """ call method of this instance (ae.gui_app.MainAppBase method). """
 
     @abstractmethod
-    def change_app_state(self, state_name: str, new_value: Any, send_event: bool = True):
+    def change_app_state(self, state_name: str, state_value: Any, send_event: bool = True):
         """ add debug sound on each state change/save (ae.gui_app.MainAppBase method). """
 
     @abstractmethod
